chordtools.get_note_head_from_chord_by_pitch
============================================

.. autofunction:: abjad.tools.chordtools.get_note_head_from_chord_by_pitch.get_note_head_from_chord_by_pitch
